function benchmark(X,titstr)
%
% this code benchmarks classificaiton performance on the 
% test dataset and produces a confusion matrix between 
% the 12 grass species
%
% Charless Fowlkes <fowlkes@ics.uci.edu> (c) 2013
%


load pollen_metadata.mat

if (size(X,1)>size(X,2))
  X = X';
end

% vector of class labels...  in 1..12
%X = floor(rand(1,120)*12)+1;  % random guess
correct = (X==pollen.class);

% build confusion matrix
confusion = zeros(12,12);
ct = 1;
for cct = 1:12
  for sct = 1:10
    idx = pollen.pp(ct);
    predclass = X(idx); 
    trueclass = cct;
    confusion(trueclass,predclass) = confusion(trueclass,predclass) + 1;
    ct = ct + 1;
  end
end
confusion = confusion / 10;

% reorder to match luke's preferred order used in the paper
order = [1 4 8 9 11 3 6 10 12 2 5 7]; 
confusion = confusion(order,:);
confusion = confusion(:,order);


figure; clf;
imagesc(confusion); axis image; caxis([0 1]); colormap gray; colorbar;
title(sprintf('%s : accuracy %3.3f',strrep(titstr,'_','-'),sum(correct)/120));

for i = 1:12
  names{i} = strrep(pollen.species(order(i)).name,'_','-');
end
set(gca,'ytick',1:12);
set(gca,'yticklabel',names);
set(gca,'xtick',1:12);
set(gca,'xticklabel',[]);
text(1:12,12.5*ones(12,1),names,'rotation',-90)

[xx,yy] = meshgrid(1:12,1:12);
text(xx(:),yy(:),num2str(confusion(:)),'color','r')


