%
% Demonstration of pollen texture classification based on sparse
% coding of 5x5 pixel patches.  This uses a generic codebook vector computed
% from a database of natural images
%
%  see: X. Ren, L. Bo, Discriminatively Trained Sparse Code Gradients for Contour Detection, NIPS 2012
%
% Each grass pollen texture image is represented by the sum (histogram)
% of the code vectors over the image.  These vectors are classified using
% a nearst neighbor classifier with the L1 metric.
%
% This method achieves a classification accuracy of ~77%
%
% Copyright (c) 2013 Charless Fowlkes <fowlkes@ics.uci.edu>
%
% sparse coding routines provided by Xiaofeng Ren
%

load('scg_model_Lab.mat');  %load up a pre trained dictionary
model = scg_model_Lab;
addpath omp/
%addpath scg_v1/

scale = 0.4;  %scale images down for best results with this dictionary

if (0)
  % code training examples
  impath = 'train/';
  ct = 1;
  for class = 1:12
    for sample = 1:10
      fprintf('\r %d',ct);
      img{class,sample} = imread(sprintf('%s%2.2d_%2.2d.tif',impath,class,sample));
      img_gray=double(imresize(img{class,sample},scale));
      omp_codes_gray=compute_omp_codes(img_gray,model.dic_gray);
      v{class,sample} = squeeze(sum(sum(omp_codes_gray,1),2));
      vv(:,ct) = v{class,sample};
      cc(ct) = class;
      ct=  ct + 1;
    end
  end

  % code test examples 
  impath = 'testblind/';
  img = {};
  testv = [];
  for ct = 1:120
    fprintf('\r %d',ct);
    img{ct} = imread(sprintf('%s%3.3d.tif',impath,ct));
    img_gray=double(imresize(img{ct},scale));
    omp_codes_gray=compute_omp_codes(img_gray,model.dic_gray);
    testv(:,ct) = squeeze(sum(sum(omp_codes_gray,1),2));
    %visualize index map  of largest coefficient 
    %[val,ind] = max(omp_codes_gray,[],3);
    %figure(1); imagesc(ind); axis image; drawnow;
  end
  save histcodes.mat v vv cc testv
else
  % coding takes a minute so just load in precomputed results 
  load histcodes.mat
end

% benchmark the results
benchmark(knnclassify(testv', vv', cc', 1, 'cityblock'),'knn-l1');

